@@ -1,4 +1,4 @@
 # Copyright (c) 2013-2015 University Corporation for Atmospheric Research/Unidata.
 # Distributed under the terms of the MIT License.
 # SPDX-License-Identifier: MIT
-"""Contains  functionality for retreiving simple web sevice data."""
+"""Contains functionality for retrieving simple web service data."""
